gedidb.GranuleParser
====================

.. currentmodule:: gedidb

.. autoclass:: GranuleParser

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GranuleParser.__init__
      ~GranuleParser.parse
      ~GranuleParser.parse_granule
   
   

   
   
   